// CPPgGuiTweaks implementation file

#ifdef PRECOMP
#	include "xmule-headers.h"
#else
#	include "wintypes.h"
#	include "xmule.h"
#	include "PPgGuiTweaks.h"
#endif

#include <wx/slider.h>
#include "wx/xrc/xmlres.h"
#include "wx/xrc/xh_all.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

#include <wx/notebook.h>
#include <wx/checkbox.h>
#include <wx/textctrl.h>


IMPLEMENT_DYNAMIC_CLASS(CPPgGuiTweaks,wxPanel)


CPPgGuiTweaks::CPPgGuiTweaks(wxWindow* parent)
  : wxPanel(parent,CPPgGuiTweaks::IDD)
{
  // Getting preferences dialog notebook
  wxNotebook* book= (wxNotebook*) parent;

  // Load Sources Dropping panel from xml resource
  wxPanel* page1 = _panel = wxXmlResource::Get()->LoadPanel(this,"DLG_PPG_GUI_TWEAKS");
  // Add this panel into preferences dialog notebook
  //book->AddPage(this,_("GUI Tweaks"));

  // looks stupid? it is :)
  SetSize(page1->GetSize().GetWidth(),page1->GetSize().GetHeight()+60);
  page1->SetSize(GetSize());
}

CPPgGuiTweaks::~CPPgGuiTweaks()
{
}

void CPPgGuiTweaks::Localize(void)
{
}

void CPPgGuiTweaks::LoadSettings(void)
{
}

void CPPgGuiTweaks::OnApply()
{
}
